@@ -77,14 +77,14 @@ export class CommentBox extends React.Component {
         else
           return (
             <h5 className="mt-4 mb-5 text-center text-info">
-              Only registered users can post comments.
+              {django.gettext("Only registered users can post comments.")}
            </h5>
           );
       }
     } else {
       return (
         <h4 className="mt-4 mb-5 text-center text-secondary">
-          Comments are disabled for this article.
+          {django.gettext("Comments are disabled for this article.")}
         </h4>
       );
     }
